import {
  messages,
  ruleName,
} from ".."
import rules from "../../../rules"
import { testRule } from "../../../testUtils"

const rule = rules[ruleName]

testRule(rule, {
  ruleName,
  config: ["always"],

  accept: [ {
    code: "a {\n\n --custom-prop: value;\n}",
  }, {
    code: "a {\r\n\r\n --custom-prop: value;\r\n}",
  }, {
    code: "a{\n\n --custom-prop: value; }",
  }, {
    code: "a{\n\n --custom-prop: value;\r\n\r\n --custom-prop2: value;}",
  }, {
    code: "a{\n\n --custom-prop: value;\n\r\n --custom-prop2: value;}",
  }, {
    code: "a{\n top: 10px;\n\r\n --custom-prop: value;}",
  }, {
    code: "a{\n @extends .class;\n\r\n --custom-prop: value;}",
  }, {
    code: "a{\n $var: value;\n\r\n --custom-prop: value;}",
  } ],

  reject: [ {
    code: "a {\n--custom-prop: value;\n}",
    message: messages.expected,
    line: 2,
    column: 1,
  }, {
    code: "a {\r\n --custom-prop: value;\r\n}",
    message: messages.expected,
    line: 2,
    column: 2,
  }, {
    code: "a{\n\n --custom-prop: value; \n --custom-prop2: value;}",
    message: messages.expected,
    line: 4,
    column: 2,
  }, {
    code: "a{\r\n\r\n --custom-prop: value;\r\n --custom-prop2: value;}",
    message: messages.expected,
    line: 4,
    column: 2,
  }, {
    code: "a{\n top: 10px;\n --custom-prop: value;}",
    message: messages.expected,
    line: 3,
    column: 2,
  }, {
    code: "a{\n @extends .class;\r\n --custom-prop: value;}",
    message: messages.expected,
    line: 3,
    column: 2,
  }, {
    code: "a{\n $var: value;\n --custom-prop: value;}",
    message: messages.expected,
    line: 3,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "always", { ignore: ["after-comment"] } ],

  accept: [ {
    code: "a {\n/* comment */ --custom-prop: value;\n}",
  }, {
    code: "a {\n/* comment */\n--custom-prop: value;\n}",
  }, {
    code: "a {\r\n/* comment */\r\nn--custom-prop: value;\r\n}",
  } ],

  reject: [{
    code: "a {\n --custom-prop: value;\n}",
    message: messages.expected,
    line: 2,
    column: 2,
  }],
})

testRule(rule, {
  ruleName,
  config: [ "always", { ignore: ["inside-single-line-block"] } ],

  accept: [ {
    code: "a { --custom-prop: value; }",
  }, {
    code: "a {\n\n --custom-prop: value;\n}",
  } ],

  reject: [{
    code: "a {\n --custom-prop: value;\n}",
    message: messages.expected,
    line: 2,
    column: 2,
  }],
})

testRule(rule, {
  ruleName,
  config: [ "always", { except: ["first-nested"] } ],

  accept: [ {
    code: "a { --custom-prop: value;\n}",
  }, {
    code: "a {\n --custom-prop: value;\n}",
  }, {
    code: "a {\r\n --custom-prop: value;\r\n}",
  } ],

  reject: [ {
    code: "a {\n\n --custom-prop: value;\n}",
    message: messages.rejected,
    line: 3,
    column: 2,
  }, {
    code: "a {\r\n\r\n --custom-prop: value;\r\n}",
    message: messages.rejected,
    line: 3,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "always", { except: ["after-comment"] } ],

  accept: [ {
    code: "a {\n\n --custom-prop: value;\n}",
  }, {
    code: "a {/* I am a comment */ \n --custom-prop2: value;}",
  }, {
    code: "a {/* I am a comment */ \r\n --custom-prop2: value;}",
  } ],

  reject: [ {
    code: "a {\n\n --custom-prop: value;\n /* I am a comment */ \n\n --custom-prop2: value;}",
    message: messages.rejected,
    line: 6,
    column: 2,
  }, {
    code: "a {\n /* I am a comment */ \r\n\r\n --custom-prop2: value;}",
    message: messages.rejected,
    line: 4,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "always", { except: ["after-custom-property"] } ],

  accept: [ {
    code: "a {\n\n --custom-prop: value;\n}",
  }, {
    code: "a {\n\n --custom-prop:value; \n --custom-prop2: value;}",
  }, {
    code: "a {\n\n --custom-prop:value; \r\n --custom-prop2: value;}",
  } ],

  reject: [ {
    code: "a {\n\n --custom-prop:value;\n\n --custom-prop2: value;}",
    message: messages.rejected,
    line: 5,
    column: 2,
  }, {
    code: "a {\n\n --custom-prop: value;\r\n\r\n --custom-prop2: value;}",
    message: messages.rejected,
    line: 5,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "always", {
    except: [
      "first-nested",
      "after-comment",
      "after-custom-property",
    ] } ],

  accept: [{ code: "a {\n --custom-prop: value; \n --custom-prop2: value; \n /* comment */ \n --custom-prop3: value;\n\n @extends 'x';\n\n --custom-prop4: value; \n & b {\n prop: value;\n } \n\n --custom-prop5: value; \n }" }],

})

testRule(rule, {
  ruleName,
  config: ["never"],

  accept: [ {
    code: "a {\n --custom-prop: value;\n}",
  }, {
    code: "a {\r\n --custom-prop: value;\r\n}",
  }, {
    code: "a {\n --custom-prop: value; \n --custom-prop2: value; \n\n /* comment */ \n --custom-prop3: value; \n\n @extends 'x'; \n --custom-prop4: value; \n\n & b {\n prop: value; \n } \n --custom-prop5: value;\n }",
  }, {
    code: "a{\n top: 10px;\n --custom-prop: value;}",
  }, {
    code: "a{\n @extends .class;\n --custom-prop: value;}",
  }, {
    code: "a{\n $var: value;\n --custom-prop: value;}",
  } ],

  reject: [ {
    code: "a {\n\n --custom-prop: value;\n}",
    message: messages.rejected,
    line: 3,
    column: 2,
  }, {
    code: "a {\r\n\r\n --custom-prop: value;\r\n}",
    message: messages.rejected,
    line: 3,
    column: 2,
  }, {
    code: "a{\n top: 10px;\n\n --custom-prop: value;}",
    message: messages.rejected,
    line: 4,
    column: 2,
  }, {
    code: "a{\n @extends .class;\n\r\n --custom-prop: value;}",
    message: messages.rejected,
    line: 4,
    column: 2,
  }, {
    code: "a{\n $var: value;\n\n --custom-prop: value;}",
    message: messages.rejected,
    line: 4,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "never", { except: ["first-nested"] } ],

  accept: [ {
    code: "a {\n\n --custom-prop: value;\n}",
  }, {
    code: "a {\n\n --custom-prop: value;\n}",
  }, {
    code: "a {\r\n\r\n --custom-prop: value;\r\n}",
  } ],

  reject: [ {
    code: "a {\n --custom-prop: value;\n}",
    message: messages.expected,
    line: 2,
    column: 2,
  }, {
    code: "a {\r\n --custom-prop: value;\r\n}",
    message: messages.expected,
    line: 2,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "never", { except: ["after-comment"] } ],

  accept: [ {
    code: "a {\n --custom-prop: value;\n}",
  }, {
    code: "a {/* I am a comment */ \n\n --custom-prop2: value;}",
  }, {
    code: "a {/* I am a comment */ \r\n\r\n --custom-prop2: value;}",
  } ],

  reject: [ {
    code: "a {\n --custom-prop: value;\n /* I am a comment */ \n --custom-prop2: value;}",
    message: messages.expected,
    line: 4,
    column: 2,
  }, {
    code: "a {\n /* I am a comment */ \r\n --custom-prop2: value;}",
    message: messages.expected,
    line: 3,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "never", { except: ["after-custom-property"] } ],

  accept: [ {
    code: "a {\n --custom-prop: value;\n}",
  }, {
    code: "a {\n --custom-prop:value; \n\n --custom-prop2: value;}",
  }, {
    code: "a {\n --custom-prop:value; \r\n\r\n --custom-prop2: value;}",
  } ],

  reject: [ {
    code: "a {\n --custom-prop:value;\n--custom-prop2: value;}",
    message: messages.expected,
    line: 3,
    column: 1,
  }, {
    code: "a {\n --custom-prop: value;\n --custom-prop2: value;}",
    message: messages.expected,
    line: 3,
    column: 2,
  } ],
})

testRule(rule, {
  ruleName,
  config: [ "never", {
    except: [
      "first-nested",
      "after-comment",
      "after-custom-property",
    ] } ],

  accept: [{ code: "a {\n\n --custom-prop: value; \n\n --custom-prop2: value; \n /* comment */ \n\n --custom-prop3: value;\n\n @extends 'x';\n --custom-prop4: value; \n & b {\n prop: value;\n } \n --custom-prop5: value; \n }" }],

})
